@@ -1,6 +1,8 @@
 use super::*;
 use crate::error::Error;
 
+type Result<T> = std::result::Result<T, util::Error>;
+
 const CHANNEL_TYPE_RELIABLE: u8 = 0x00;
 const CHANNEL_TYPE_RELIABLE_UNORDERED: u8 = 0x80;
 const CHANNEL_TYPE_PARTIAL_RELIABLE_REXMIT: u8 = 0x01;
@@ -429,8 +431,8 @@ mod tests {
             channel_type: ChannelType::Reliable,
             priority: 3893,
             reliability_parameter: 16715573,
-            label: b"label".iter().cloned().collect(),
-            protocol: b"protocol".iter().cloned().collect(),
+            label: b"label".to_vec(),
+            protocol: b"protocol".to_vec(),
         };
 
         let marshal_size = channel_open.marshal_size();
@@ -445,8 +447,8 @@ mod tests {
             channel_type: ChannelType::Reliable,
             priority: 3893,
             reliability_parameter: 16715573,
-            label: b"label".iter().cloned().collect(),
-            protocol: b"protocol".iter().cloned().collect(),
+            label: b"label".to_vec(),
+            protocol: b"protocol".to_vec(),
         };
 
         let mut buf = BytesMut::with_capacity(11 + 5 + 8);
